<?php

namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO\Response\{ Error, Message };

use Ems\portalGestor\Service\MarcacaoService;
use Ems\portalGestor\Util\ExpectedException;

class MarcacaoController {
    /** @var MarcacaoService */
    protected $marcacaoService;

    public function __construct(MarcacaoService $marcacaoService) {
        $this->marcacaoService = $marcacaoService;
    }

    public function registraMarcacaoHcmServices(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $marcacao = $this->marcacaoService->registraMarcacaoHcmServices($row);

            $response->addDataSet(new DataSet('data', $marcacao));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function registraMarcacaoAlmocoHcmServices(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $marcacao = $this->marcacaoService->registraMarcacaoAlmocoHcmServices($row);

            $response->addDataSet(new DataSet('data', $marcacao));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function insertAlmocoGestor(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrOrg      = (int)     $row['NRORG'];
            $cdOperador = (string)  $row['CDOPERADOR'];
            $nrVinculo  = (int)     $row['NRVINCULOM'];
            $date       = (string)  $row['DATE'];
            $nrMarcacao = (int)     $row['NRMARCACAOPONTO'];

            $success = $this->marcacaoService->
                insertAlmocoGestor($nrOrg, $cdOperador, $nrVinculo, $date, $nrMarcacao);

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function insertAlmocoMultiplesGestor(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrOrg      = (int)     $row['NRORG'];
            $cdOperador = (string)  $row['CDOPERADOR'];
            $nrVinculo  = (int)     $row['NRVINCULOM'];
            $dates      = (array)   $row['DATE'];

            $success = $this->marcacaoService->
                insertAlmocoMultiplesGestor($nrOrg, $cdOperador, $nrVinculo, $dates);

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function removeAlmocoGestor(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];
            $date      = (string) $row['DATE'];

            $success = $this->marcacaoService->
                removeAlmocoGestor($nrOrg, $nrVinculo, $date);

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getMarcacoesFotos(
        Request\Filter $request,
        Response $response
    ){
        try {
            $row = $request->getParameters();

            $nrOrg     = (int)    $row['NRORG'];
            $nrVinculo = (int)    $row['NRVINCULOM'];
            $date      = (string) $row['DATE'];

            $filesData = $this->marcacaoService->getMarcacoesFotos(
                $nrOrg, $nrVinculo, $date
            );

            $response->addDataSet(new DataSet('data', $filesData));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function setEntradasSaidasFixos(
        Request\Row $request,
        Response $response
    ){
        try {
            $row = $request->getRow();

            $nrOrg          = (int)     $row['NRORG'];
            $nrVinculo      = (int)     $row['NRVINCULOM'];
            $cdOperador     = (string)  $row['CDOPERADOR'];
            $marcacoes      = (array)   $row['ROWS'];

            $filesData = $this->marcacaoService->setEntradasSaidasFixos(
                $nrOrg, $nrVinculo, $cdOperador, $marcacoes
            );

            $response->addDataSet(new DataSet('data', $filesData));
        } catch(ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getDetalheAcompanhamento(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $params = $request->getParameters();

            $nrOrg      = (int)   $params['NRORG'];
            $nrVinculo  = (int)   $params['NRVINCULOM'];
            $date       = (array) $params['DATES'];

            $detalhesAcompanhamento = $this->marcacaoService->getDetalheAcompanhamento(
                $nrOrg, $nrVinculo, $date
            );

            $response->addDataSet(new DataSet('data', $detalhesAcompanhamento));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function removeMarcacao(
        Request\Row $request,
        Response $response
    ) {
        try {
            $params = $request->getRow();

            $nrOrg      = (int)   $params['NRORG'];
            $nrVinculo  = (int)   $params['NRVINCULOM'];
            $nrMarcacao = (int)   $params['NRMARCACAOPONTO'];

            $success = $this->marcacaoService->removeMarcacao(
                $nrOrg, $nrVinculo, $nrMarcacao
            );

            $dataset = [
                'success' => $success,
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function removeParesMarcacao(
        DTO\Request\Row     $request,
        DTO\Response        $response
    ) {

        try {
            $row = $request->getRow()->getArrayCopy();

            $nrMarcacoes = $this->marcacaoService->removeParesMarcacao($row);

            $dataSet = [
                'nrMarcacoes' => $nrMarcacoes
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function editParesMarcacao(
        DTO\Request\Row     $request,
        DTO\Response        $response
    ) {

        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->marcacaoService->editParesMarcacao($row);

            $dataSet = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
}
