/******************************************************************************/
/* Sistemas Integrados TEKNISA                                                */
/* Nome: 0009_CARSTPO_USR_IMPORTARECEITA.SQL                                  */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que as receitas locais                  */
/* ajustadas pelo Portal sejam importadas                                     */
/* no sistema da Teknisa e, para isso, a procedure verificar                 */
/* uma tabela intermediria entre os dois sistemas (tabelas pertencentes      */
/* ao banco de dados do sistema da Teknisa).                                  */
/* Criao:                                                                   */
/* 31/01/2012 - Marcelo Alexsandro                                            */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_IMPORTARECEITA IS
   V_DTGRV          DATE;
   V_HRGRV          VARCHAR2(4);
   V_QTDEAUX        FLOAT;
   V_QTDEBRUTA      FLOAT;
   V_QTDELIQUIDA    FLOAT;
   V_QTENUTRIENTE   FLOAT;
   V_FATORDIFUNID   FLOAT;
   V_RETURN         VARCHAR2(1);
   V_ERROR          VARCHAR2(4000);
   /* - Declarao de cursores ---------------------------------------------- */
   CURSOR C_FILIAIS IS
      SELECT CDFILIAL
        FROM FILGRUPFILI
       WHERE FILGRUPFILI.CDGRUPFILI = '9999999999';
BEGIN
   V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_RECEFILI', 'B');
   IF V_RETURN = 'S' THEN
      V_DTGRV := NULL;
      V_HRGRV := NULL;
      FOR C_RECEFILI IN
        (SELECT
            R.NRSEQUENCIAL,
            R.CDFILAUXPRAT,
            R.CDPRATO,
            R.CDFILIAL,
            PR.CDPRODUTO,
            PR.CDARVPROD,
            R.QTLIQUIDA,
            R.QTBRUTA,
            R.IDORIGREGISTRO,
            P.IDQTLIQUBRUT,
            PR.SGUNIDADE
           FROM USR_INT_RECEFILI R, PARAMPLANEJA P, PRODUTO PR
          WHERE R.DTIMPORTACAO IS NULL
            AND R.HRIMPORTACAO IS NULL
            AND R.DTGRAVACAO   IS NOT NULL
            AND R.HRGRAVACAO   IS NOT NULL
            AND R.IDORIGREGISTRO = 'P'
            AND R.CDFILIAL = P.CDFILIAL
            AND R.CDPRODUTO = PR.CDARVPROD
            AND PR.CDPRODUTO = PR.CDPRODESTO
            AND EXISTS (SELECT 1
                          FROM FILGRUPFILI
                         WHERE FILGRUPFILI.CDGRUPFILI = '9999999999'
                           AND FILGRUPFILI.CDFILIAL = R.CDFILIAL)
         ORDER BY R.NRSEQUENCIAL, R.CDFILAUXPRAT, R.CDPRATO, R.CDFILIAL, R.CDPRODUTO
        )
      LOOP
        FOR C_AUXRECEFILI IN
           (SELECT VRPEFATCOCLO, VRPEFATCORLO, VRPEFATNUTLO, SGUNIDADE
              FROM RECEFILI
             WHERE RECEFILI.CDFILAUXPRAT = C_RECEFILI.CDFILAUXPRAT
               AND RECEFILI.CDPRATO = C_RECEFILI.CDPRATO
               AND RECEFILI.CDFILIAL = C_RECEFILI.CDFILIAL
               AND RECEFILI.CDPRODUTO = C_RECEFILI.CDPRODUTO
           )
        LOOP
           IF C_RECEFILI.IDQTLIQUBRUT = 'B' THEN
              IF C_RECEFILI.QTBRUTA IS NOT NULL THEN
                 V_QTDEAUX     := C_RECEFILI.QTBRUTA * (100 / (100 + C_AUXRECEFILI.VRPEFATCOCLO));
                 V_QTDELIQUIDA := V_QTDEAUX * (100 / (100 - C_AUXRECEFILI.VRPEFATCORLO));
                 V_QTDEBRUTA   := C_RECEFILI.QTBRUTA;
              END IF;
           ELSE
              IF C_RECEFILI.QTLIQUIDA IS NOT NULL  THEN
                 V_QTDEAUX      := C_RECEFILI.QTLIQUIDA * (100 / (100 + C_AUXRECEFILI.VRPEFATCOCLO));
                 V_QTDEBRUTA    := V_QTDEAUX * (100 / (100 - C_AUXRECEFILI.VRPEFATCORLO));
                 V_QTDELIQUIDA  := C_RECEFILI.QTLIQUIDA;
              END IF;
           END IF;
           V_FATORDIFUNID := 1;
           IF C_AUXRECEFILI.SGUNIDADE IS NOT NULL THEN
              IF C_RECEFILI.SGUNIDADE <> C_AUXRECEFILI.SGUNIDADE THEN
                 FOR C_CONVPRODUTO IN
                    (SELECT CONVPRODUTO.VRFATOCONVES AS VRFTCONVER
                       FROM CONVPRODUTO
                      WHERE CDPRODUTO = C_RECEFILI.CDPRODUTO
                        AND SGUNIDADE = C_AUXRECEFILI.SGUNIDADE
                     UNION ALL
                     SELECT CONVUNID.VRFTCONVER AS VRFTCONVER
                       FROM CONVUNID
                      WHERE SGUNIDPARA = C_RECEFILI.SGUNIDADE
                        AND SGUNIDDE = C_AUXRECEFILI.SGUNIDADE)
                 LOOP
                    V_FATORDIFUNID := C_CONVPRODUTO.VRFTCONVER;
                    EXIT;
                 END LOOP;
              END IF;
           END IF;
           V_QTENUTRIENTE := (V_QTDELIQUIDA * V_FATORDIFUNID * C_AUXRECEFILI.VRPEFATNUTLO) / 100;

           IF (V_QTDELIQUIDA > 0) AND (V_QTDEBRUTA > 0) AND (V_QTENUTRIENTE > 0) THEN
              UPDATE RECEFILI
                 SET QTPRODRECLOC = V_QTDELIQUIDA,
                     QTUNIDESTLO = V_QTDELIQUIDA,
                     QTBRUTALO = V_QTDEBRUTA,
                     QTBRUTALOUNR = V_QTDEBRUTA,
                     QTCALCNUTRLO = V_QTENUTRIENTE
               WHERE RECEFILI.CDFILAUXPRAT = C_RECEFILI.CDFILAUXPRAT
                  AND RECEFILI.CDPRATO = C_RECEFILI.CDPRATO
                  AND RECEFILI.CDFILIAL = C_RECEFILI.CDFILIAL
                  AND RECEFILI.CDPRODUTO = C_RECEFILI.CDPRODUTO;

              UPDATE USR_INT_RECEFILI
                 SET DTIMPORTACAO = TO_DATE(SYSDATE),
                     HRIMPORTACAO = TO_CHAR(SYSDATE, 'HH24MI')
              WHERE NRSEQUENCIAL = C_RECEFILI.NRSEQUENCIAL
                AND CDFILAUXPRAT = C_RECEFILI.CDFILAUXPRAT
                AND CDPRATO = C_RECEFILI.CDPRATO
                AND CDFILIAL = C_RECEFILI.CDFILIAL
                AND CDPRODUTO = C_RECEFILI.CDARVPROD;
           END IF;
           EXIT;
        END LOOP;
      END LOOP;
      COMMIT;
      V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_RECEFILI', 'D');
   END IF;
EXCEPTION
  WHEN OTHERS THEN BEGIN
     IF V_RETURN = 'S' THEN
        V_ERROR:= SQLERRM(SQLCODE);
        V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_RECEFILI', 'D', V_ERROR);
     END IF;
  END;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_IMPORTARECEITA','5.09.xxx'); END;
/

